@@ -57,15 +57,15 @@ public:
           TauGroup_t ProfileGroup = TAU_DEFAULT, 
 	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = false,
 	  int tid = RtsLayer::myThread());
-	FunctionInfo(const char* name, string& type, 
+	FunctionInfo(const char* name, const string& type, 
 	  TauGroup_t ProfileGroup = TAU_DEFAULT,
 	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = false,
 	  int tid = RtsLayer::myThread());
-	FunctionInfo(string& name, string& type, 
+	FunctionInfo(const string& name, const string& type, 
 	  TauGroup_t ProfileGroup = TAU_DEFAULT,
 	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = false,
 	  int tid = RtsLayer::myThread());
-	FunctionInfo(string& name, const char * type, 
+	FunctionInfo(const string& name, const char * type, 
 	  TauGroup_t ProfileGroup = TAU_DEFAULT,
 	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = false,
 	  int tid = RtsLayer::myThread());
@@ -146,6 +146,8 @@ public:
 	const char* GetName() const { return Name.c_str(); }
 	const char* GetType() const { return Type.c_str(); }
 	const char* GetPrimaryGroup() const { return GroupName.c_str(); }
+	void SetPrimaryGroupName(const char *newname) { GroupName = newname; }
+	void SetPrimaryGroupName(string newname) { GroupName = newname; }
 	long GetFunctionId() ;
 	long GetCalls(int tid) { return NumCalls[tid]; }
 	void SetCalls(int tid, long calls) { NumCalls[tid] = calls; }
@@ -217,9 +219,10 @@ FunctionInfo::GetAlreadyOnStack(int tid)
 {
 	return AlreadyOnStack[tid];
 }
+
 #endif /* _FUNCTIONINFO_H_ */
 /***************************************************************************
  * $RCSfile: FunctionInfo.h,v $   $Author: sameer $
- * $Revision: 1.11 $   $Date: 2000/10/11 18:41:20 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.11 2000/10/11 18:41:20 sameer Exp $ 
+ * $Revision: 1.15 $   $Date: 2001/10/03 20:59:13 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.15 2001/10/03 20:59:13 sameer Exp $ 
  ***************************************************************************/
