@@ -36,11 +36,11 @@
 
 #include <Profile/ProfileGroups.h>
 
-#if (defined(PTHREADS) || defined(TULIPTHREADS) || defined(JAVA) || defined(TAU_WINDOWS) || defined (_OPENMP))
+#if (defined(PTHREADS) || defined(TULIPTHREADS) || defined(JAVA) || defined(TAU_WINDOWS) || defined (TAU_OPENMP) || defined (TAU_SPROC))
 #define TAU_MAX_THREADS 128
 #else
 #define TAU_MAX_THREADS 1
-#endif /* PTHREADS || TULIPTHREADS || JAVA || TAU_WINDOWS*/
+#endif /* PTHREADS || TULIPTHREADS || JAVA || TAU_WINDOWS || OPENMP || SPROC */
 
 #include <Profile/TauAPI.h>
 
@@ -54,6 +54,8 @@
 
 #include <Profile/JavaThreadLayer.h>
 
+#include <Profile/SprocLayer.h>
+
 #include <Profile/RtsLayer.h>
 
 
@@ -93,7 +95,9 @@ public:
 	~Profiler();
   	static void ProfileExit(const char *message=0, 
 	  int tid = RtsLayer::myThread());
-	static int StoreData(int tid); 
+	static int StoreData(int tid = RtsLayer::myThread()); 
+	static int DumpData(int tid = RtsLayer::myThread()); 
+	static void PurgeData(int tid = RtsLayer::myThread());
 
 #if ( defined(PROFILE_CALLS) || defined(PROFILE_STATS) || defined(PROFILE_CALLSTACK) ) 
 	int ExcludeTimeThisCall(double t);
@@ -110,7 +114,7 @@ public:
 #ifdef PROFILE_CALLSTACK
   	double InclTime_cs;
   	double ExclTime_cs;
-  	static void CallStackTrace();
+  	static void CallStackTrace(int tid = RtsLayer::myThread());
 #endif /* PROFILE_CALLSTACK  */
 
 private:
@@ -134,6 +138,6 @@ private:
 #endif /* PROFILER_H */
 /***************************************************************************
  * $RCSfile: Profiler.h,v $   $Author: sameer $
- * $Revision: 1.29 $   $Date: 2000/12/01 19:29:38 $
- * POOMA_VERSION_ID: $Id: Profiler.h,v 1.29 2000/12/01 19:29:38 sameer Exp $ 
+ * $Revision: 1.32 $   $Date: 2001/06/20 20:25:53 $
+ * POOMA_VERSION_ID: $Id: Profiler.h,v 1.32 2001/06/20 20:25:53 sameer Exp $ 
  ***************************************************************************/
