@@ -53,7 +53,19 @@
 #define TAU_PROFILE_INIT(argc, argv) RtsLayer::ProfileInit(argc, argv);
 #define TAU_PROFILE_SET_NODE(node) RtsLayer::setMyNode(node);
 #define TAU_PROFILE_SET_CONTEXT(context) RtsLayer::setMyContext(context);
+#define TAU_PROFILE_SET_GROUP_NAME(newname) tauFI.SetPrimaryGroupName(newname);
+#define TAU_PROFILE_TIMER_SET_GROUP_NAME(t, newname) t##fi.SetPrimaryGroupName(newname);
 
+#define TAU_GLOBAL_TIMER(timer, name, type, group) static FunctionInfo timer##fi(name, type, group, #group);
+#define TAU_GLOBAL_TIMER_START(timer) FunctionInfo *timer##fptr = &timer##fi; \
+        int tau_tid = RtsLayer::myThread(); \
+        Profiler *timer = new Profiler(timer##fptr, timer##fptr != (FunctionInfo *) 0 ? timer##fptr->GetProfileGroup() : TAU_DEFAULT, true, tau_tid); \
+        timer->Start(tau_tid);
+
+#define TAU_GLOBAL_TIMER_STOP()  {int tau_threadid = RtsLayer::myThread(); \
+                Profiler::CurrentProfiler[tau_threadid]->Stop(tau_threadid);}
+
+/* The above macros are for use with global timers in a multi-threaded application */
 
 #ifdef PROFILE_CALLSTACK
 #define TAU_PROFILE_CALLSTACK()    Profiler::CallStackTrace();
@@ -61,6 +73,9 @@
 #define TAU_PROFILE_CALLSTACK() 
 #endif /* PROFILE_CALLSTACK */
 
+#define TAU_DB_DUMP() Profiler::DumpData();
+#define TAU_DB_PURGE() Profiler::PurgeData();
+
 // UserEvents
 #define TAU_REGISTER_EVENT(event, name)  	TauUserEvent event(name);
 #define TAU_EVENT(event, data) 		 	(event).TriggerEvent(data);
@@ -75,9 +90,12 @@
 #define TAU_REGISTER_FORK(id, op) 		RtsLayer::RegisterFork(id, op);
 #define TAU_ENABLE_INSTRUMENTATION() 		RtsLayer::TheEnableInstrumentation() = true;
 #define TAU_DISABLE_INSTRUMENTATION() 		RtsLayer::TheEnableInstrumentation() = false;
+#define TAU_ENABLE_GROUP(group)			RtsLayer::enableProfileGroup(group)
+#define TAU_DISABLE_GROUP(group)		RtsLayer::disableProfileGroup(group)
 
 #ifdef NO_RTTI
-#define CT(obj) string(#obj)
+/* #define CT(obj) string(#obj) */
+#define CT(obj) " "
 #else // RTTI is present
 #define CT(obj) string(RtsLayer::CheckNotNull(typeid(obj).name())) 
 #endif //NO_RTTI
@@ -97,7 +115,11 @@
 #define TAU_PROFILE_INIT(argc, argv)
 #define TAU_PROFILE_SET_NODE(node)
 #define TAU_PROFILE_SET_CONTEXT(context)
+#define TAU_PROFILE_SET_GROUP_NAME(newname)
+#define TAU_PROFILE_TIMER_SET_GROUP_NAME(t, newname)
 #define TAU_PROFILE_CALLSTACK()    
+#define TAU_DB_DUMP()
+#define TAU_DB_PURGE()
 
 #define TAU_REGISTER_EVENT(event, name)
 #define TAU_EVENT(event, data)
@@ -111,6 +133,8 @@
 #define TAU_REGISTER_FORK(id, op) 
 #define TAU_ENABLE_INSTRUMENTATION() 		
 #define TAU_DISABLE_INSTRUMENTATION() 	
+#define TAU_ENABLE_GROUP(group)
+#define TAU_DISABLE_GROUP(group)
 
 #define CT(obj)
 
@@ -137,6 +161,6 @@
 #endif /* _TAU_API_H_ */
 /***************************************************************************
  * $RCSfile: TauAPI.h,v $   $Author: sameer $
- * $Revision: 1.6 $   $Date: 2000/10/12 19:12:24 $
- * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.6 2000/10/12 19:12:24 sameer Exp $ 
+ * $Revision: 1.13 $   $Date: 2001/08/28 18:42:44 $
+ * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.13 2001/08/28 18:42:44 sameer Exp $ 
  ***************************************************************************/
