@@ -48,6 +48,9 @@
 
 #define TAU_PROFILE_TIMER(var,name, type, group) static void *var=NULL; tau_profile_c_timer(&var, name, type, group);
 
+#define TAU_PROFILE_DECLARE_TIMER(var) static void *var=NULL;
+#define TAU_PROFILE_CREATE_TIMER(var,name,type,group) tau_profile_c_timer(&var, name, type, group);
+
 
 #define TAU_PROFILE_START(var) 			tau_start_timer(var);
 #define TAU_PROFILE_STOP(var) 			tau_stop_timer(var);
@@ -57,6 +60,9 @@
 #define TAU_PROFILE_SET_NODE(node) 		tau_set_node(node);
 #define TAU_PROFILE_SET_CONTEXT(context)	tau_set_context(context);
 #define TAU_PROFILE_CALLSTACK()			tau_callstack();
+#define TAU_DB_DUMP()                           tau_dump();
+#define TAU_DB_PURGE()                          tau_purge();
+
 /*
 #define TAU_REGISTER_EVENT(event, name)	static int tauuser##event = 1;\
 				        static void *event; \ 
@@ -87,6 +93,8 @@
 #define TAU_REGISTER_FORK(nodeid, op) 		tau_register_fork(nodeid, op);
 #define TAU_ENABLE_INSTRUMENTATION()		tau_enable_instrumentation();
 #define TAU_DISABLE_INSTRUMENTATION()		tau_disable_instrumentation();
+#define TAU_ENABLE_GROUP(group)			tau_enable_group(group);
+#define TAU_DISABLE_GROUP(group)		tau_disable_group(group);
 
 extern void * tau_get_profiler(char *fname, char *type, TauGroup_t  group);
 extern void tau_start_timer(void *profiler);
@@ -96,6 +104,8 @@ extern void tau_init(int argc, char **argv);
 extern void tau_set_node(int node);
 extern void tau_set_context(int context);
 extern void tau_callstack(void);
+extern int tau_dump(void);
+extern void tau_purge(void);
 extern void tau_register_thread();
 extern void tau_register_fork(int nodeid, enum TauFork_t opcode);
 extern void * tau_get_userevent(char *name);
@@ -126,6 +136,8 @@ extern void tau_trace_recvmsg(int type, int source, int length);
 #define TAU_PROFILE_SET_NODE(node)
 #define TAU_PROFILE_SET_CONTEXT(context)
 #define TAU_PROFILE_CALLSTACK()
+#define TAU_DB_DUMP()
+#define TAU_DB_PURGE()
 
 #define TAU_REGISTER_EVENT(event, name)
 #define TAU_EVENT(event, data)
@@ -137,6 +149,11 @@ extern void tau_trace_recvmsg(int type, int source, int length);
 #define TAU_EVENT_DISABLE_STDDEV(event)
 #define TAU_STORE_ALL_EVENTS
 #define TAU_REGISTER_THREAD()
+#define TAU_REGISTER_FORK(nodeid, op) 		
+#define TAU_ENABLE_INSTRUMENTATION()	
+#define TAU_DISABLE_INSTRUMENTATION()
+#define TAU_ENABLE_GROUP(group)	
+#define TAU_DISABLE_GROUP(group)
 
 #define CT(obj)
 
@@ -159,7 +176,7 @@ extern void tau_trace_recvmsg(int type, int source, int length);
 
 /***************************************************************************
  * $RCSfile: TauCAPI.h,v $   $Author: sameer $
- * $Revision: 1.8 $   $Date: 2000/10/12 19:12:24 $
- * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.8 2000/10/12 19:12:24 sameer Exp $
+ * $Revision: 1.11 $   $Date: 2001/02/28 00:03:28 $
+ * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.11 2001/02/28 00:03:28 sameer Exp $
  ***************************************************************************/
 
