@@ -33,7 +33,7 @@
 //#define DEBUG_PROF // For Debugging Messages from Profiler.cpp
 #include "Profile/Profiler.h"
 
-
+extern "C" void tau_disable_instrumentation(void);
 #ifdef TAU_DOT_H_LESS_HEADERS
 #include <iostream>
 using namespace std;
@@ -135,6 +135,7 @@ void Profiler::Start(int tid)
 	
 	// Initialization is over, now record the time it started
 	StartTime =  RtsLayer::getUSecD(tid) ;
+	DEBUGPROFMSG("Start Time = "<< StartTime<<endl;);
 #endif // PROFILING_ON
   	
 	ParentProfiler = CurrentProfiler[tid] ;
@@ -229,7 +230,7 @@ void Profiler::Stop(int tid)
       DEBUGPROFMSG("Profiler::Stop: MyProfileGroup_ = " << MyProfileGroup_ 
         << " Mask = " << RtsLayer::TheProfileMask() <<endl;);
       if ((MyProfileGroup_ & RtsLayer::TheProfileMask()) 
-	  && RtsLayer::TheEnableInstrumentation()){
+	  && RtsLayer::TheEnableInstrumentation()) {
 	if (ThisFunction == (FunctionInfo *) NULL) return; // Mapping
 #ifdef TRACING_ON
 	TraceEvent(ThisFunction->GetFunctionId(), -1, tid); // -1 is for exit
@@ -313,10 +314,14 @@ void Profiler::Stop(int tid)
 	      << ThisFunction->GetType() <<endl;);
 	  if (CurrentProfiler[tid] != (Profiler *) NULL) {
 	    if (CurrentProfiler[tid]->ThisFunction != (FunctionInfo *)NULL) {
+#ifdef TAU_OPENMP
 #pragma omp critical
+#endif /* TAU_OPENMP */
 	      cout << "Overlapping function = "
                  << CurrentProfiler[tid]->ThisFunction->GetName () << " " 
-		 << CurrentProfiler[tid]->ThisFunction->GetType() <<endl;
+		 << CurrentProfiler[tid]->ThisFunction->GetType() 
+		 << " Other function " << this->ThisFunction->GetName()
+	 	 << this->ThisFunction->GetType()<< " Tid = "<<tid<<endl;
 	    } else {
 	      cout <<"CurrentProfiler is not Null but its FunctionInfo is"<<endl;
 	    }
@@ -327,6 +332,7 @@ void Profiler::Stop(int tid)
  	DEBUGPROFMSG("nct "<< RtsLayer::myNode() << ","
             << RtsLayer::myContext() << "," << tid
 	    << " Stop: " << ThisFunction->GetName() 
+	    << " TheSafeToDumpData() = " << TheSafeToDumpData()
 	    << " CurrProf = "<<CurrentProfiler[tid] << " this = "
 	    << this<<endl;);
 
@@ -334,6 +340,7 @@ void Profiler::Stop(int tid)
 	  // For Dyninst. tcf gets called after main and all the data structures may not be accessible
 	  // after main exits. Still needed on Linux - we use TauProgramTermination()
 	  if (strcmp(ThisFunction->GetName(), "_fini") == 0) TheSafeToDumpData() = 0;
+	  atexit(tau_disable_instrumentation); 
   	  if (TheSafeToDumpData()) {
             if (!RtsLayer::isCtorDtor(ThisFunction->GetName())) {
             // Not a destructor of a static object - its a function like main
@@ -343,7 +350,7 @@ void Profiler::Stop(int tid)
               << ThisFunction->GetName() <<endl;);
   
               StoreData(tid);
-            }
+	    }
         // dump data here. Dump it only at the exit of top level profiler.
 	  }
         }
@@ -579,6 +586,257 @@ int Profiler::StoreData(int tid)
 
 //////////////////////////////////////////////////////////////////////
 
+int Profiler::DumpData(int tid)
+{
+  	TAU_PROFILE("TAU_DUMP_DB()", " ", TAU_IO);
+#ifdef PROFILING_ON 
+	vector<FunctionInfo*>::iterator it;
+  	vector<TauUserEvent*>::iterator eit;
+	char *filename, *dumpfile, *errormsg, *header;
+	char *dirname;
+	FILE* fp;
+ 	int numFunc, numEvents;
+#endif //PROFILING_ON
+#ifdef PROFILE_CALLS
+	long listSize, numCalls;
+	list<pair<double,double> >::iterator iter;
+#endif // PROFILE_CALLS
+ 	double excltime, incltime; 
+	double currenttime, prevtime, total;
+
+	DEBUGPROFMSG("Profiler::DumpData( tid = "<<tid <<" ) "<<endl;);
+
+#ifdef TRACING_ON
+	TraceEvClose(tid);
+	RtsLayer::DumpEDF(tid);
+#endif // TRACING_ON 
+
+#ifdef PROFILING_ON 
+	currenttime = RtsLayer::getUSecD(tid); 
+	RtsLayer::LockDB();
+	if ((dirname = getenv("PROFILEDIR")) == NULL) {
+	// Use default directory name .
+	   dirname  = new char[8];
+	   strcpy (dirname,".");
+	}
+	 
+	filename = new char[1024];
+	sprintf(filename,"%s/temp.%d.%d.%d",dirname, RtsLayer::myNode(),
+		RtsLayer::myContext(), tid);
+	DEBUGPROFMSG("Creating " << filename << endl;);
+	/* Changed: TRUNCATE dump file */ 
+	if ((fp = fopen (filename, "w+")) == NULL) {
+	 	errormsg = new char[1024];
+		sprintf(errormsg,"Error: Could not create %s",filename);
+		perror(errormsg);
+		return 0;
+	}
+
+	// Data format :
+	// %d templated_functions
+	// "%s %s" %ld %G %G  
+	//  funcname type numcalls Excl Incl
+	// %d aggregates
+	// <aggregate info>
+       
+	// Recalculate number of funcs using ProfileGroup. Static objects 
+        // constructed before setting Profile Groups have entries in FuncDB 
+	// (TAU_DEFAULT) even if they are not supposed to be there.
+	numFunc = 0;
+ 	for (it = TheFunctionDB().begin(); it != TheFunctionDB().end(); it++)
+	{
+          if ((*it)->GetProfileGroup() & RtsLayer::TheProfileMask()) { 
+	    numFunc++;
+	  }
+	}
+	header = new char[256];
+
+#if (defined (SGI_HW_COUNTERS) || defined (TAU_PCL) \
+	|| (defined (TAU_PAPI) && \
+         (!(defined(TAU_PAPI_WALLCLOCKTIME) || (defined (TAU_PAPI_VIRTUAL))))))
+	sprintf(header,"%d templated_functions_hw_counters\n", numFunc);
+#else  // SGI_TIMERS, TULIP_TIMERS 
+	sprintf(header,"%d templated_functions\n", numFunc);
+#endif // SGI_HW_COUNTERS 
+
+	// Send out the format string
+	strcat(header,"# Name Calls Subrs Excl Incl ");
+#ifdef PROFILE_STATS
+	strcat(header,"SumExclSqr ");
+#endif //PROFILE_STATS
+	strcat(header,"ProfileCalls\n");
+	int sz = strlen(header);
+	int ret = fprintf(fp, "%s",header);	
+	ret = fflush(fp);
+	/*
+	if (ret != sz) {
+	  cout <<"ret not equal to strlen "<<endl;
+ 	}
+        cout <<"Header: "<< tid << " : bytes " <<ret <<":"<<header ;
+	*/
+ 	for (it = TheFunctionDB().begin(); it != TheFunctionDB().end(); it++)
+	{
+          if ((*it)->GetProfileGroup() & RtsLayer::TheProfileMask())
+	  { 
+
+	    if ((*it)->GetAlreadyOnStack(tid)) 
+	    { 
+	      /* it is on the callstack. We need to do some processing. */
+	      /* Calculate excltime, incltime */
+	      Profiler *current; 
+	      /* Traverse the Callstack */
+	      current = CurrentProfiler[tid];
+	  
+	      if (current == 0)
+	      { /* current is null */
+		DEBUGPROFMSG("Current is NULL when it should be on the stack! TID = " << tid << endl;);
+	      }
+	      else 
+	      { /* current is not null */
+		incltime = (*it)->GetInclTime(tid); 
+		excltime = (*it)->GetExclTime(tid); 
+		total = 0;  /* Initialize what gets added */
+		prevtime = 0; /* for reducing from the parent profiler */
+		while (current != 0) 
+		{
+		  /* Traverse the stack */ 
+		  if ((*it) == current->ThisFunction) 
+	 	  { /* Match! */
+		    DEBUGPROFMSG("MATCH! Name :"<<current->ThisFunction->GetName()
+	  	      <<endl;);
+		    total = currenttime - current->StartTime; 
+		    excltime += total - prevtime; 
+		    /* prevtime is the inclusive time of the subroutine that should
+		       be subtracted from the current exclusive time */ 
+		    /* If there is no instance of this function higher on the 	
+			callstack, we should add the total to the inclusive time */
+		  }
+        	  prevtime = currenttime - current->StartTime;  
+		  /* to calculate exclusive time */
+
+	          current = current->ParentProfiler; 
+	        } /* We've reached the top! */
+		incltime += total; /* add this to the inclusive time */ 
+		/* prevtime and incltime are calculated */
+	      } /* Current is not null */
+	    } /* On call stack */
+ 	    else 
+	    { /* it is not on the callstack. */ 
+	      excltime = (*it)->GetExclTime(tid);
+	      incltime = (*it)->GetInclTime(tid); 
+	    } // Not on the Callstack
+
+	    DEBUGPROFMSG("Node: "<< RtsLayer::myNode() <<  " Dumping " 
+  	      << (*it)->GetName()<< " "  << (*it)->GetType() << " Calls : " 
+              << (*it)->GetCalls(tid) << " Subrs : "<< (*it)->GetSubrs(tid) 
+  	      << " Excl : " << excltime << " Incl : " << incltime << endl;);
+  	
+  	    fprintf(fp,"\"%s %s\" %ld %ld %.16G %.16G ", (*it)->GetName(), 
+  	      (*it)->GetType(), (*it)->GetCalls(tid), (*it)->GetSubrs(tid), 
+	      excltime, incltime); 
+
+  	    fprintf(fp,"0 \n"); // Indicating - profile calls is turned off 
+	  } // ProfileGroup test 
+	} // for loop. End of FunctionInfo data
+	fprintf(fp,"0 aggregates\n"); // For now there are no aggregates
+	// Change this when aggregate profiling in introduced in Pooma 
+
+	// Print UserEvent Data if any
+	
+	numEvents = 0;
+ 	for (eit = TheEventDB().begin(); eit != TheEventDB().end(); eit++)
+	{
+          if ((*eit)->GetNumEvents(tid)) { 
+	    numEvents++;
+	  }
+	}
+
+	if (numEvents > 0) {
+    	// Data format 
+    	// # % userevents
+    	// # name numsamples max min mean sumsqr 
+    	  fprintf(fp, "%d userevents\n", numEvents);
+    	  fprintf(fp, "# eventname numevents max min mean sumsqr\n");
+
+    	  vector<TauUserEvent*>::iterator it;
+    	  for(it  = TheEventDB().begin(); it != TheEventDB().end(); it++)
+    	  {
+      
+	    DEBUGPROFMSG("Thr "<< tid << " TauUserEvent "<<
+              (*it)->GetEventName() << "\n Min " << (*it)->GetMin(tid) 
+              << "\n Max " << (*it)->GetMax(tid) << "\n Mean " 
+	      << (*it)->GetMean(tid) << "\n SumSqr " << (*it)->GetSumSqr(tid) 
+	      << "\n NumEvents " << (*it)->GetNumEvents(tid)<< endl;);
+
+     	    fprintf(fp, "\"%s\" %ld %.16G %.16G %.16G %.16G\n", 
+	    (*it)->GetEventName(), (*it)->GetNumEvents(tid), (*it)->GetMax(tid),
+	    (*it)->GetMin(tid), (*it)->GetMean(tid), (*it)->GetSumSqr(tid));
+    	  }
+	}
+	// End of userevents data 
+
+	RtsLayer::UnLockDB();
+	fclose(fp);
+	dumpfile = new char[1024];
+        sprintf(dumpfile,"%s/dump.%d.%d.%d",dirname, RtsLayer::myNode(),
+                RtsLayer::myContext(), tid);
+	rename(filename, dumpfile); 
+
+
+#endif //PROFILING_ON
+	return 1;
+}
+
+void Profiler::PurgeData(int tid)
+{
+	vector<FunctionInfo*>::iterator it;
+	vector<TauUserEvent*>::iterator eit;
+	Profiler *curr;
+
+	DEBUGPROFMSG("Profiler::PurgeData( tid = "<<tid <<" ) "<<endl;);
+	RtsLayer::LockDB();
+
+	// Reset The Function Database (save callstack entries)
+	for(it = TheFunctionDB().begin(); it != TheFunctionDB().end(); it++) {
+// May be able to recycle fns which never get called again??
+	    (*it)->SetCalls(tid,0);
+	    (*it)->SetSubrs(tid,0);
+	    (*it)->SetExclTime(tid,0);
+	    (*it)->SetInclTime(tid,0);
+#ifdef PROFILE_STATS
+	    (*it)->SetSumExclSqr(tid,0);
+#endif //PROFILE_STATS
+#ifdef PROFILE_CALLS
+	    (*it)->ExclInclCallList->clear();
+#endif // PROFILE_CALLS
+/*
+	  }
+*/
+	}
+	// Now Re-register callstack entries
+	curr = CurrentProfiler[tid];
+	curr->ThisFunction->IncrNumCalls(tid);
+	curr = curr->ParentProfiler;
+	while(curr != 0) {
+	  curr->ThisFunction->IncrNumCalls(tid);
+	  curr->ThisFunction->IncrNumSubrs(tid);
+	  curr = curr->ParentProfiler;
+	}
+
+	// Reset the Event Database
+	for (eit = TheEventDB().begin(); eit != TheEventDB().end(); eit++) {
+	  (*eit)->LastValueRecorded[tid] = 0;
+	  (*eit)->NumEvents[tid] = 0L;
+	  (*eit)->MinValue[tid] = 9999999;
+	  (*eit)->MaxValue[tid] = -9999999;
+	  (*eit)->SumSqrValue[tid] = 0;
+	  (*eit)->SumValue[tid] = 0;
+	}
+
+	RtsLayer::UnLockDB();
+}
+//////////////////////////////////////////////////////////////////////
+
 #if ( defined(PROFILE_CALLS) || defined(PROFILE_STATS) || defined(PROFILE_CALLSTACK) )
 int Profiler::ExcludeTimeThisCall(double t)
 {
@@ -719,8 +977,8 @@ void Profiler::CallStackTrace(int tid)
 
 /***************************************************************************
  * $RCSfile: Profiler.cpp,v $   $Author: sameer $
- * $Revision: 1.42 $   $Date: 2000/10/12 19:04:31 $
- * POOMA_VERSION_ID: $Id: Profiler.cpp,v 1.42 2000/10/12 19:04:31 sameer Exp $ 
+ * $Revision: 1.49 $   $Date: 2001/08/30 17:23:21 $
+ * POOMA_VERSION_ID: $Id: Profiler.cpp,v 1.49 2001/08/30 17:23:21 sameer Exp $ 
  ***************************************************************************/
 
 	
