@@ -102,7 +102,7 @@ using namespace std;
 /////////////////////////////////////////////////////////////////////////
 TauGroup_t& RtsLayer::TheProfileMask(void)
 { // to avoid initialization problems of non-local static variables
-  static unsigned int ProfileMask = TAU_DEFAULT;
+  static TauGroup_t ProfileMask = TAU_DEFAULT;
 
   return ProfileMask;
 }
@@ -133,7 +133,7 @@ int& RtsLayer::TheContext(void)
 
 /////////////////////////////////////////////////////////////////////////
 
-unsigned int RtsLayer::enableProfileGroup(unsigned int ProfileGroup) {
+TauGroup_t RtsLayer::enableProfileGroup(TauGroup_t ProfileGroup) {
   TheProfileMask() |= ProfileGroup; // Add it to the mask
   DEBUGPROFMSG("enableProfileGroup " << ProfileGroup <<" Mask = " 
 	<< TheProfileMask() << endl;);
@@ -142,7 +142,18 @@ unsigned int RtsLayer::enableProfileGroup(unsigned int ProfileGroup) {
 
 /////////////////////////////////////////////////////////////////////////
 
-unsigned int RtsLayer::resetProfileGroup(void) {
+TauGroup_t RtsLayer::disableProfileGroup(TauGroup_t ProfileGroup) {
+  if (TheProfileMask() & ProfileGroup) { // if it is already set 
+    TheProfileMask() ^= ProfileGroup; // Delete it from the mask
+    DEBUGPROFMSG("disableProfileGroup " << ProfileGroup <<" Mask = " 
+	<< TheProfileMask() << endl;);
+  } // if it is not in the mask, disableProfileGroup does nothing 
+  return TheProfileMask();
+}
+
+/////////////////////////////////////////////////////////////////////////
+
+TauGroup_t RtsLayer::resetProfileGroup(void) {
   TheProfileMask() = 0;
   return TheProfileMask();
 }
@@ -178,8 +189,8 @@ int RtsLayer::setMyContext(int ContextId) {
 
 /////////////////////////////////////////////////////////////////////////
 
-bool RtsLayer::isEnabled(unsigned int ProfileGroup) {
-unsigned int res =  ProfileGroup & TheProfileMask() ;
+bool RtsLayer::isEnabled(TauGroup_t ProfileGroup) {
+TauGroup_t res =  ProfileGroup & TheProfileMask() ;
 
   if (res > 0)
     return true;
@@ -526,18 +537,119 @@ int RtsLayer::setAndParseProfileGroups(char *prog, char *str)
 	case 'V' : // ACLVIZ Group
 	  RtsLayer::enableProfileGroup(TAU_VIZ);
 	  break;
+ 	case '0' :
+	  RtsLayer::enableProfileGroup(TAU_GROUP_0);
+	  break;
 	case '1' : // User1
-	  RtsLayer::enableProfileGroup(TAU_USER1);
-	  break; 
+	  switch (str[1])
+	  {
+	    case '0':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_10);
+	      break; 
+	    case '1':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_11);
+	      break; 
+	    case '2':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_12);
+	      break; 
+	    case '3':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_13);
+	      break; 
+	    case '4':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_14);
+	      break; 
+	    case '5':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_15);
+	      break; 
+	    case '6':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_16);
+	      break; 
+	    case '7':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_17);
+	      break; 
+	    case '8':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_18);
+	      break; 
+	    case '9':
+	      RtsLayer::enableProfileGroup(TAU_GROUP_19);
+	      break; 
+	    default :
+	      RtsLayer::enableProfileGroup(TAU_GROUP_1);
+	      break; 
+	  }
+	  break;
+	 
 	case '2' : // User2
-	  RtsLayer::enableProfileGroup(TAU_USER2);
+          switch (str[1])
+          {
+            case '0':
+              RtsLayer::enableProfileGroup(TAU_GROUP_20);
+              break;
+            case '1':
+              RtsLayer::enableProfileGroup(TAU_GROUP_21);
+              break;
+            case '2':
+              RtsLayer::enableProfileGroup(TAU_GROUP_22);
+              break;
+            case '3':
+              RtsLayer::enableProfileGroup(TAU_GROUP_23);
+              break;
+            case '4':
+              RtsLayer::enableProfileGroup(TAU_GROUP_24);
+              break;
+            case '5':
+              RtsLayer::enableProfileGroup(TAU_GROUP_25);
+              break;
+            case '6':
+              RtsLayer::enableProfileGroup(TAU_GROUP_26);
+              break; 
+            case '7':
+              RtsLayer::enableProfileGroup(TAU_GROUP_27);
+              break;
+            case '8':
+              RtsLayer::enableProfileGroup(TAU_GROUP_28);
+              break;
+            case '9':
+              RtsLayer::enableProfileGroup(TAU_GROUP_29);
+              break;
+            default :
+              RtsLayer::enableProfileGroup(TAU_GROUP_2);
+              break;
+	  }
 	  break;
 	case '3' : // User3
-	  RtsLayer::enableProfileGroup(TAU_USER3);
-	  break; 
-	case '4' : // User4
-	  RtsLayer::enableProfileGroup(TAU_USER4);
+          switch (str[1])
+          {
+            case '0':
+              RtsLayer::enableProfileGroup(TAU_GROUP_30);
+              break;
+            case '1':
+              RtsLayer::enableProfileGroup(TAU_GROUP_31);
+              break;
+            default :
+              RtsLayer::enableProfileGroup(TAU_GROUP_3);
+              break;
+	  }
 	  break;
+	case '4' : // User4
+	  RtsLayer::enableProfileGroup(TAU_GROUP_4);
+	  break;
+	case '5' : 
+	  RtsLayer::enableProfileGroup(TAU_GROUP_5);
+	  break;
+	case '6' : 
+	  RtsLayer::enableProfileGroup(TAU_GROUP_6);
+	  break;
+	case '7' : 
+	  RtsLayer::enableProfileGroup(TAU_GROUP_7);
+	  break;
+	case '8' : 
+	  RtsLayer::enableProfileGroup(TAU_GROUP_8);
+	  break;
+	case '9' : 
+	  RtsLayer::enableProfileGroup(TAU_GROUP_9);
+	  break;
+
 	default  :
 	  cout << prog << " : Invalid Profile Group " << str << endl;
 	  break; 
@@ -585,13 +697,18 @@ bool RtsLayer::isCtorDtor(const char *name)
       DEBUGPROFMSG("JAVA RtsLayer::isCtorDtor("<<name<<") returns false! "<<endl;);
       return false;
 #endif /* JAVA */
-  if (strchr(name,'~') == NULL) // a destructor 
-    if (strchr(name,':') == NULL) // could be a constructor 
-      return false;
+  if (myThread() == 0) 
+  {
+    if (strchr(name,'~') == NULL) // a destructor 
+      if (strchr(name,':') == NULL) // could be a constructor 
+        return false;
+      else  
+        return true; /* in C++ a : in a name could signify a ctor/dtor */
     else  
-      return true; /* in C++ a : in a name could signify a ctor/dtor */
-  else  
-    return true;
+      return true;
+  }
+  else 
+    return false; /* in C++, on other threads don't check for this */
 }
 
 //////////////////////////////////////////////////////////////////////
@@ -755,6 +872,6 @@ int RtsLayer::DumpEDF(int tid)
 
 /***************************************************************************
  * $RCSfile: RtsLayer.cpp,v $   $Author: sameer $
- * $Revision: 1.24 $   $Date: 2000/12/01 19:27:21 $
- * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.24 2000/12/01 19:27:21 sameer Exp $ 
+ * $Revision: 1.27 $   $Date: 2001/10/02 21:03:19 $
+ * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.27 2001/10/02 21:03:19 sameer Exp $ 
  ***************************************************************************/
