@@ -72,6 +72,8 @@ int RtsLayer::myThread(void)
 {
 #ifdef PTHREADS
   return PthreadLayer::GetThreadId();
+#elif  TAU_SPROC
+  return SprocLayer::GetThreadId();
 #elif  TAU_WINDOWS
   return WindowsThreadLayer::GetThreadId();
 #elif  TULIPTHREADS
@@ -79,7 +81,7 @@ int RtsLayer::myThread(void)
 #elif JAVA
   return JavaThreadLayer::GetThreadId(); 
 	// C++ app shouldn't use this unless there's a VM
-#elif _OPENMP
+#elif TAU_OPENMP
   return OpenMPLayer::GetThreadId();
 #else  // if no other thread package is available 
   return 0;
@@ -95,11 +97,13 @@ void RtsLayer::RegisterThread()
 {
 #ifdef PTHREADS
   PthreadLayer::RegisterThread();
+#elif TAU_SPROC
+  SprocLayer::RegisterThread();
 #elif  TAU_WINDOWS
   WindowsThreadLayer::RegisterThread();
 #elif  TULIPTHREADS
   TulipThreadLayer::RegisterThread();
-#elif _OPENMP
+#elif TAU_OPENMP
   OpenMPLayer::RegisterThread();
 #endif // PTHREADS
 // Note: Java thread registration is done at the VM layer in TauJava.cpp
@@ -185,13 +189,15 @@ void RtsLayer::LockDB(void)
 {
 #ifdef PTHREADS
   PthreadLayer::LockDB();
+#elif TAU_SPROC
+  SprocLayer::LockDB();
 #elif  TAU_WINDOWS
   WindowsThreadLayer::LockDB();
 #elif  TULIPTHREADS
   TulipThreadLayer::LockDB();
 #elif  JAVA
   JavaThreadLayer::LockDB();
-#elif _OPENMP
+#elif TAU_OPENMP
   OpenMPLayer::LockDB();
 #endif // PTHREADS
   return ; // do nothing if threads are not used
@@ -205,13 +211,15 @@ void RtsLayer::UnLockDB(void)
 {
 #ifdef PTHREADS
   PthreadLayer::UnLockDB();
+#elif TAU_SPROC
+  SprocLayer::UnLockDB();
 #elif  TAU_WINDOWS
   WindowsThreadLayer::UnLockDB();
 #elif  TULIPTHREADS
   TulipThreadLayer::UnLockDB();
 #elif JAVA
   JavaThreadLayer::UnLockDB();
-#elif _OPENMP
+#elif TAU_OPENMP
   OpenMPLayer::UnLockDB();
 #endif // PTHREADS
   return;
@@ -221,8 +229,8 @@ void RtsLayer::UnLockDB(void)
 
 /***************************************************************************
  * $RCSfile: RtsThread.cpp,v $   $Author: sameer $
- * $Revision: 1.14 $   $Date: 2000/10/12 19:33:56 $
- * VERSION: $Id: RtsThread.cpp,v 1.14 2000/10/12 19:33:56 sameer Exp $
+ * $Revision: 1.16 $   $Date: 2001/06/20 20:31:51 $
+ * VERSION: $Id: RtsThread.cpp,v 1.16 2001/06/20 20:31:51 sameer Exp $
  ***************************************************************************/
 
 
